==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControl/src/com/clustercontrol/bean/RunIntervalConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * ¹Դֳ饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class RunIntervalConstant {
	
    /** ʥ塼μ̡ */
    public static final int EVERY_HOUR = 0;

    /** ʬʥ塼μ̡ */
    public static final int EVERY_MINUTE = 1;

    /** áʥ塼μ̡ */
    public static final int EVERY_SECOND = 2;

    /** 1 */
    public static final int TYPE_SEC_01 = 1;

    /** 5 */
    public static final int TYPE_SEC_05 = 5;
    
    /** 15 */
    public static final int TYPE_SEC_15 = 15;
    
    /** 30 */
    public static final int TYPE_SEC_30 = 30;

    /** 1ʬ */
    public static final int TYPE_MIN_01 = 60;

    /** 5ʬ */
    public static final int TYPE_MIN_05 = 300;
    
    /** 15ʬ */
    public static final int TYPE_MIN_15 = 900;
    
    /** 30ʬ */
    public static final int TYPE_MIN_30 = 1800;

    /** 60ʬ */
    public static final int TYPE_MIN_60 = 3600;

    /** 1 */
    public static final String STRING_SEC_01 = TYPE_SEC_01 + Messages.getString("second");

    /** 5 */
    public static final String STRING_SEC_05 = TYPE_SEC_05 + Messages.getString("second");
    
    /** 15 */
    public static final String STRING_SEC_15 = TYPE_SEC_15 + Messages.getString("second");
    
    /** 30 */
    public static final String STRING_SEC_30 = TYPE_SEC_30 + Messages.getString("second");
    
    /** 1ʬ */
    public static final String STRING_MIN_01 = TYPE_MIN_01/60 + Messages.getString("minute");

    /** 5ʬ */
    public static final String STRING_MIN_05 = TYPE_MIN_05/60 + Messages.getString("minute");
    
    /** 15ʬ */
    public static final String STRING_MIN_15 = TYPE_MIN_15/60 + Messages.getString("minute");
    
    /** 30ʬ */
    public static final String STRING_MIN_30 = TYPE_MIN_30/60 + Messages.getString("minute");
    
    /** 60ʬ */
    public static final String STRING_MIN_60 = TYPE_MIN_60/60 + Messages.getString("minute");

    /**
     * ̤ʸѴ
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
    	if (type == TYPE_SEC_01) {
            return STRING_SEC_01;
        } else if (type == TYPE_SEC_05) {
            return STRING_SEC_05;
        } else if (type == TYPE_SEC_15) {
            return STRING_SEC_15;
        } else if (type == TYPE_SEC_30) {
            return STRING_SEC_30;
        } else if (type == TYPE_MIN_01) {
            return STRING_MIN_01;
        } else if (type == TYPE_MIN_05) {
            return STRING_MIN_05;
        } else if (type == TYPE_MIN_15) {
            return STRING_MIN_15;
        } else if (type == TYPE_MIN_30) {
            return STRING_MIN_30;
        } else if (type == TYPE_MIN_60) {
            return STRING_MIN_60;
        }
        return "";
    }

    /**
     * ʸ󤫤̤Ѵ
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_SEC_01)) {
            return TYPE_SEC_01;
        } else if (string.equals(STRING_SEC_05)) {
            return TYPE_SEC_05;
        } else if (string.equals(STRING_SEC_15)) {
            return TYPE_SEC_15;
        } else if (string.equals(STRING_SEC_30)) {
            return TYPE_SEC_30;
        } else if (string.equals(STRING_MIN_01)) {
            return TYPE_MIN_01;
        } else if (string.equals(STRING_MIN_05)) {
            return TYPE_MIN_05;
        } else if (string.equals(STRING_MIN_15)) {
            return TYPE_MIN_15;
        } else if (string.equals(STRING_MIN_30)) {
            return TYPE_MIN_30;
        } else if (string.equals(STRING_MIN_60)) {
            return TYPE_MIN_60;
        }
        return -1;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControl/src/com/clustercontrol/bean/RunIntervalConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.bean;

import com.clustercontrol.util.Messages;

/**
 * 実行間隔定数クラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class RunIntervalConstant {
	
    /** 毎時（スケジュールの種別） */
    public static final int EVERY_HOUR = 0;

    /** 毎分（スケジュールの種別） */
    public static final int EVERY_MINUTE = 1;

    /** 毎秒（スケジュールの種別） */
    public static final int EVERY_SECOND = 2;

    /** 1秒 */
    public static final int TYPE_SEC_01 = 1;

    /** 5秒 */
    public static final int TYPE_SEC_05 = 5;
    
    /** 15秒 */
    public static final int TYPE_SEC_15 = 15;
    
    /** 30秒 */
    public static final int TYPE_SEC_30 = 30;

    /** 1分 */
    public static final int TYPE_MIN_01 = 60;

    /** 5分 */
    public static final int TYPE_MIN_05 = 300;
    
    /** 15分 */
    public static final int TYPE_MIN_15 = 900;
    
    /** 30分 */
    public static final int TYPE_MIN_30 = 1800;

    /** 60分 */
    public static final int TYPE_MIN_60 = 3600;

    /** 1秒 */
    public static final String STRING_SEC_01 = TYPE_SEC_01 + Messages.getString("second");

    /** 5秒 */
    public static final String STRING_SEC_05 = TYPE_SEC_05 + Messages.getString("second");
    
    /** 15秒 */
    public static final String STRING_SEC_15 = TYPE_SEC_15 + Messages.getString("second");
    
    /** 30秒 */
    public static final String STRING_SEC_30 = TYPE_SEC_30 + Messages.getString("second");
    
    /** 1分 */
    public static final String STRING_MIN_01 = TYPE_MIN_01/60 + Messages.getString("minute");

    /** 5分 */
    public static final String STRING_MIN_05 = TYPE_MIN_05/60 + Messages.getString("minute");
    
    /** 15分 */
    public static final String STRING_MIN_15 = TYPE_MIN_15/60 + Messages.getString("minute");
    
    /** 30分 */
    public static final String STRING_MIN_30 = TYPE_MIN_30/60 + Messages.getString("minute");
    
    /** 60分 */
    public static final String STRING_MIN_60 = TYPE_MIN_60/60 + Messages.getString("minute");

    /**
     * 種別から文字列に変換する
     * 
     * @param type
     * @return
     */
    public static String typeToString(int type) {
    	if (type == TYPE_SEC_01) {
            return STRING_SEC_01;
        } else if (type == TYPE_SEC_05) {
            return STRING_SEC_05;
        } else if (type == TYPE_SEC_15) {
            return STRING_SEC_15;
        } else if (type == TYPE_SEC_30) {
            return STRING_SEC_30;
        } else if (type == TYPE_MIN_01) {
            return STRING_MIN_01;
        } else if (type == TYPE_MIN_05) {
            return STRING_MIN_05;
        } else if (type == TYPE_MIN_15) {
            return STRING_MIN_15;
        } else if (type == TYPE_MIN_30) {
            return STRING_MIN_30;
        } else if (type == TYPE_MIN_60) {
            return STRING_MIN_60;
        }
        return "";
    }

    /**
     * 文字列から種別に変換する
     * 
     * @param type
     * @return
     */
    public static int stringToType(String string) {
        if (string.equals(STRING_SEC_01)) {
            return TYPE_SEC_01;
        } else if (string.equals(STRING_SEC_05)) {
            return TYPE_SEC_05;
        } else if (string.equals(STRING_SEC_15)) {
            return TYPE_SEC_15;
        } else if (string.equals(STRING_SEC_30)) {
            return TYPE_SEC_30;
        } else if (string.equals(STRING_MIN_01)) {
            return TYPE_MIN_01;
        } else if (string.equals(STRING_MIN_05)) {
            return TYPE_MIN_05;
        } else if (string.equals(STRING_MIN_15)) {
            return TYPE_MIN_15;
        } else if (string.equals(STRING_MIN_30)) {
            return TYPE_MIN_30;
        } else if (string.equals(STRING_MIN_60)) {
            return TYPE_MIN_60;
        }
        return -1;
    }
}
